@@ -19,7 +19,7 @@ class ContainerChoiceBlock(blocks.ChoiceBlock):
 
 class ButtonChoiceBlock(blocks.ChoiceBlock):
     choices = constants.BUTTON_CHOICES
-    default = constants.BUTTON_GREEN_LIGHT
+    default = constants.BUTTON_PRIMARY
 
 
 class AlignTextChoiceBlock(blocks.ChoiceBlock):
